# -*- coding: utf-8 -*-
#
# Configuration file for the Sphinx documentation builder.
#
# This file does only contain a selection of the most common options. For a
# full list see the documentation:
# http://www.sphinx-doc.org/en/master/config

# -- Path setup --------------------------------------------------------------

# If extensions (or modules to document with autodoc) are in another directory,
# add these directories to sys.path here. If the directory is relative to the
# documentation root, use os.path.abspath to make it absolute, like shown here.
import os
import sys
from datetime import datetime
DOCDIR = os.path.pardir(os.path.abspath(__file__))
sys.path.insert(0, os.path.join(os.path.pardir(DOCDIR), 'getmac'))

from recommonmark.transform import AutoStructify  # noqa: E402

import getmac  # noqa: E402


# -- Project information -----------------------------------------------------

project = 'getmac'
copyright = '2017 - %i, Christopher Goes' % datetime.today().year
author = 'Christopher Goes'
version = getmac.__version__
release = getmac.__version__


# -- General configuration ---------------------------------------------------

# TODO: sphinx-copybutton
# TODO: sphinx-tabs (or another extension) to provide tabbed command
#   examples for different platforms (e.g. for developer docs and CLI usage)
# TODO(python3): sphinx-autodoc-typehints
extensions = [
    'sphinx.ext.autodoc',
    'sphinx.ext.viewcode',
]

# TODO: setup ReadTheDocs
# TODO: convert docs to RST format
source_parsers = {
    '.md': 'recommonmark.parser.CommonMarkParser',
}

# Add any paths that contain templates here, relative to this directory.
templates_path = ['_templates']

# The suffix(es) of source filenames.
source_suffix = ['.md']  # , '.rst'

# The master toctree document.
master_doc = 'index'

# List of patterns, relative to source directory, that match files and
# directories to ignore when looking for source files.
# This pattern also affects html_static_path and html_extra_path.
exclude_patterns = []

# The name of the Pygments (syntax highlighting) style to use.
pygments_style = 'sphinx'  # None


# -- Options for HTML output -------------------------------------------------

# TODO: furo theme? (like the pip documentation)
html_theme = 'sphinx_rtd_theme'
# html_theme_options = {}

# Add any paths that contain custom static files (such as style sheets) here,
# relative to this directory. They are copied after the builtin static files,
# so a file named "default.css" will overwrite the builtin "default.css".
html_static_path = []  # '_static'

# Custom sidebar templates, must be a dictionary that maps document names
# to template names.
#
# The default sidebars (for documents that don't match any pattern) are
# defined by theme itself.  Builtin themes are using these templates by
# default: ``['localtoc.html', 'relations.html', 'sourcelink.html',
# 'searchbox.html']``.
#
html_sidebars = {
    '**': [
        'relations.html',  # needs 'show_related': True theme option to display
        'searchbox.html',
    ]
}

html_context = {
    "display_github": True,  # Integrate GitHub
    "github_user": "GhostofGoes",  # Username
    "github_repo": "getmac",  # Repo name
    "github_version": "main",  # Version
    "conf_py_path": "/",  # Path in the checkout to the docs root
}


# -- Options for manual page output ------------------------------------------

# One entry per manual page. List of tuples
# (source start file, name, description, authors, manual section).
# TODO: auto-build and include the man page in the release archive
man_pages = [
    (master_doc, 'getmac', 'Cross-platform Python package to get MAC addresses',
     [author], 1)
]


# -- Extension configuration -------------------------------------------------

def setup(app):
    app.add_config_value('recommonmark_config', {
        'auto_toc_tree_section': 'Contents',
        'enable_eval_rst': True,
        'enable_auto_doc_ref': True,
    }, True)
    app.add_transform(AutoStructify)



# -*- coding: utf-8 -*-
import io
from os import path

import pytest

import getmac

getmac.getmac.DEBUG = 4


@pytest.fixture()
def get_sample():
    def _get_sample(sample_path):
        sdir = path.realpath(path.join(path.dirname(__file__), "samples"))
        with io.open(
            path.join(sdir, sample_path), "rt", newline="", encoding="utf-8"
        ) as f:
            return f.read()

    return _get_sample



# -*- coding: utf-8 -*-

import platform
import socket
import sys
import uuid
from subprocess import CalledProcessError

import pytest

from getmac import getmac

# TODO: freebsd11/netstat_-ia.out
# TODO: netstat_-ian_aix.out
# TODO: netstat_-ian_unknown.out
# TODO: macos_10.12.6/netstat_-i.out
# TODO: macos_10.12.6/netstat_-ia.out


def test_darwinnetworksetupiface(benchmark, mocker, get_sample):
    content = get_sample("macos_10.12.6/networksetup_-getmacaddress_en0.out")
    mocker.patch("getmac.getmac._popen", return_value=content)
    assert "08:00:27:2b:c2:ed" == benchmark(
        getmac.DarwinNetworksetupIface().get, arg="en0"
    )

    mocker.patch("getmac.getmac._popen", return_value=None)
    assert not getmac.DarwinNetworksetupIface().get("en0")
    mocker.patch("getmac.getmac._popen", return_value="")
    assert not getmac.DarwinNetworksetupIface().get("en0")

    mocker.patch("getmac.getmac.check_command", return_value=True)
    assert getmac.DarwinNetworksetupIface().test() is True
    getmac.check_command.assert_called_once_with("networksetup")


ifconfigether_samples = [
    ("2c:f0:ee:2f:c7:de", "OSX/ifconfig.out"),
    ("08:00:27:2b:c2:ed", "macos_10.12.6/ifconfig.out"),
    ("08:00:27:2b:c2:ed", "macos_10.12.6/ifconfig_en0.out"),
]


@pytest.mark.parametrize(("mac", "sample_file"), ifconfigether_samples)
def test_ifconfigether_darwin(benchmark, mocker, get_sample, mac, sample_file):
    content = get_sample(sample_file)
    mocker.patch("getmac.getmac._popen", return_value=content)
    assert mac == benchmark(getmac.IfconfigEther().get, arg="en0")

    if sample_file == "OSX/ifconfig.out":
        assert "b2:eb:94:59:0b:d4" == getmac.IfconfigEther().get("awdl0")
        assert "32:00:10:bf:60:00" == getmac.IfconfigEther().get("bridge0")

    assert not getmac.IfconfigEther().get("en")
    assert not getmac.IfconfigEther().get("lo")
    assert not getmac.IfconfigEther().get("lo0")
    assert not getmac.IfconfigEther().get("gif0")
    assert not getmac.IfconfigEther().get("stf0")
    assert not getmac.IfconfigEther().get("XHC20")
    assert not getmac.IfconfigEther().get("utun0")


# TODO: several of these should be a different method without a interface arg
ifconfig_samples = [
    ("74:d4:35:e9:45:71", "eth0", "ifconfig.out"),
    ("00:0c:29:b5:72:37", "ens33", "ubuntu_18.04/ifconfig_ens33.out"),
    ("08:00:27:e8:81:6f", "eth0", "ubuntu_12.04/ifconfig.out"),
    ("08:00:27:e8:81:6f", "eth0", "ubuntu_12.04/ifconfig_eth0.out"),
    ("00:15:5d:83:d9:0a", "eth8", "WSL_ubuntu_18.04/ifconfig_eth8.out"),
    # NOTE: the freebsd samples were taken on different machines, hence different MACs
    ("08:00:27:33:37:26", "em0", "freebsd11/ifconfig_em0.out"),
    ("08:00:27:ab:b0:67", "em0", "freebsd11/ifconfig.out"),
    ("2c:f0:ee:2f:c7:de", "en0", "OSX/ifconfig.out"),
    ("b2:eb:94:59:0b:d4", "awdl0", "OSX/ifconfig.out"),
    ("32:00:10:bf:60:00", "bridge0", "OSX/ifconfig.out"),
    ("08:00:27:18:64:56", "em0", "openbsd_6/ifconfig.out"),
    ("08:00:27:18:64:56", "em0", "openbsd_6/ifconfig_em0.out"),
]


@pytest.mark.parametrize(("mac", "iface", "sample_file"), ifconfig_samples)
def test_parse_ifconfig_samples(benchmark, get_sample, mac, iface, sample_file):
    content = get_sample(sample_file)
    assert mac == benchmark(getmac._parse_ifconfig, iface=iface, command_output=content)

    # check trailing ":" is stripped
    assert mac == getmac._parse_ifconfig(iface + ":", content)

    # Ensure no overmatches or false-positives occur
    assert not getmac._parse_ifconfig("l", content)
    assert not getmac._parse_ifconfig("lo", content)
    assert not getmac._parse_ifconfig("lo0", content)
    assert not getmac._parse_ifconfig("lo0:", content)
    assert not getmac._parse_ifconfig("ether", content)
    assert not getmac._parse_ifconfig("eth", content)
    assert not getmac._parse_ifconfig("em", content)
    assert not getmac._parse_ifconfig("e", content)
    assert not getmac._parse_ifconfig("h0", content)
    assert not getmac._parse_ifconfig("docker0", content)
    assert not getmac._parse_ifconfig("XHC20", content)
    assert not getmac._parse_ifconfig("utun0", content)
    assert not getmac._parse_ifconfig("enc0", content)
    assert not getmac._parse_ifconfig("pflog0", content)
    assert not getmac._parse_ifconfig("", content)


def test_parse_ifconfig_bad_params():
    assert not getmac._parse_ifconfig(None, None)
    assert not getmac._parse_ifconfig("", "")
    assert not getmac._parse_ifconfig("   ", "")
    assert not getmac._parse_ifconfig("   ", "        ")
    assert not getmac._parse_ifconfig("   ", "     ether   ")


@pytest.mark.parametrize(("mac", "iface", "sample_file"), ifconfig_samples)
def test_ifconfigwithifacearg_samples(mocker, get_sample, mac, iface, sample_file):
    content = get_sample(sample_file)
    mocker.patch("getmac.getmac._popen", return_value=content)
    assert mac == getmac.IfconfigWithIfaceArg().get(iface)


def test_ifconfigwithifacearg_bad_exits(mocker):
    cpe = CalledProcessError(cmd="ifconfig", returncode=1)
    mocker.patch("getmac.getmac._popen", side_effect=cpe)
    assert getmac.IfconfigWithIfaceArg().get("eth0") is None

    cpe = CalledProcessError(cmd="ifconfig", returncode=255)
    mocker.patch("getmac.getmac._popen", side_effect=cpe)
    with pytest.raises(CalledProcessError):
        getmac.IfconfigWithIfaceArg().get("eth0")


def test_arping_host_habets(benchmark, mocker, get_sample):
    content = get_sample("ubuntu_18.04/arping-habets.out")
    mocker.patch("getmac.getmac._popen", return_value=content)

    ap = getmac.ArpingHost()
    ap._is_iputils = False
    ap.get("192.168.16.254")

    assert "00:50:56:e8:32:3c" == benchmark(ap.get, arg="192.168.16.254")


def test_arping_host_iputils(benchmark, mocker, get_sample):
    content = get_sample("ubuntu_18.04/arping-iputils.out")
    mocker.patch("getmac.getmac._popen", return_value=content)

    ap = getmac.ArpingHost()
    ap.get("192.168.16.254")

    assert "00:50:56:E8:32:3C" == benchmark(ap.get, arg="192.168.16.254")


def test_arping_host_busybox(benchmark, mocker, get_sample):
    content = get_sample("WSL2_kali_2023.1/busybox_arping_-f_-c_1_172-29-16-1.out")
    mocker.patch("getmac.getmac._popen", return_value=content)

    ap = getmac.ArpingHost()
    ap.get("172.29.16.1")

    assert "00:15:5d:20:f2:73" == benchmark(ap.get, arg="172.29.16.1")


def test_windows_10_iface_getmac_exe(benchmark, mocker, get_sample):
    content = get_sample("windows_10/getmac.out")
    mocker.patch("getmac.getmac._popen", return_value=content)
    assert "74-D4-35-E9-45-71" == benchmark(getmac.GetmacExe().get, arg="Ethernet 2")


def test_windows_10_iface_ipconfig(benchmark, mocker, get_sample):
    content = get_sample("windows_10/ipconfig-all.out")
    mocker.patch("getmac.getmac._popen", return_value=content)
    assert "74-D4-35-E9-45-71" == benchmark(getmac.IpconfigExe().get, arg="Ethernet 3")


def test_windows_10_iface_wmic(benchmark, mocker, get_sample):
    content = get_sample("windows_10/wmic_nic.out")
    mocker.patch("getmac.getmac._popen", return_value=content)
    assert "00:FF:17:15:F8:C8" == benchmark(getmac.WmicExe().get, arg="Ethernet 3")


@pytest.mark.parametrize(
    ("mac", "ip", "sample_file"),
    [("78-28-ca-c4-66-fe", "10.0.0.175", "windows_10/arp_-a_10.0.0.175.out")],
)
def test_arpexe_samples(benchmark, mocker, get_sample, mac, ip, sample_file):
    content = get_sample(sample_file)
    mocker.patch("getmac.getmac._popen", return_value=content)
    assert mac == benchmark(getmac.ArpExe().get, arg=ip)

    mocker.patch("getmac.getmac.check_command", return_value=True)
    assert getmac.ArpExe().test() is True
    getmac.check_command.assert_called_once_with("arp.exe")


def test_openbsd_get_default_iface(benchmark, mocker, get_sample):
    content = get_sample("openbsd_6/route_nq_show_inet_gateway_priority_1.out")
    mocker.patch("getmac.getmac._popen", return_value=content)
    assert "em0" == benchmark(getmac.DefaultIfaceOpenBsd().get)

    mocker.patch("getmac.getmac._popen", return_value="")
    assert not getmac.DefaultIfaceOpenBsd().get()

    mocker.patch("getmac.getmac.check_command", return_value=True)
    assert getmac.DefaultIfaceOpenBsd().test() is True
    getmac.check_command.assert_called_once_with("route")


def test_openbsd_remote(benchmark, mocker, get_sample):
    content = get_sample("openbsd_6/arp_an.out")
    mocker.patch("getmac.getmac._popen", return_value=content)
    assert "52:54:00:12:35:02" == benchmark(getmac.ArpOpenbsd().get, arg="10.0.2.2")
    assert "52:54:00:12:35:03" == getmac.ArpOpenbsd().get("10.0.2.3")
    assert "08:00:27:18:64:56" == getmac.ArpOpenbsd().get("10.0.2.15")

    mocker.patch("getmac.getmac.check_command", return_value=True)
    assert getmac.ArpOpenbsd().test() is True
    getmac.check_command.assert_called_once_with("arp")


def test_freebsd_get_default_iface(benchmark, mocker, get_sample):
    content = get_sample("freebsd11/netstat_r.out")
    mocker.patch("getmac.getmac._popen", return_value=content)
    assert "em0" == benchmark(getmac.DefaultIfaceFreeBsd().get)

    mocker.patch("getmac.getmac.check_command", return_value=True)
    assert getmac.DefaultIfaceFreeBsd().test() is True
    getmac.check_command.assert_called_once_with("netstat")


@pytest.mark.parametrize(
    ("mac", "ip", "sample_file"),
    [
        ("52:54:00:12:35:02", "10.0.2.2", "freebsd11/arp_-a.out"),
        ("08:00:27:ab:b0:67", "10.0.2.15", "freebsd11/arp_-a.out"),
        ("52:54:00:12:35:02", "10.0.2.2", "freebsd11/arp_10-0-2-2.out"),
    ],
)
def test_arpfreebsd_samples(benchmark, mocker, get_sample, mac, ip, sample_file):
    content = get_sample(sample_file)
    mocker.patch("getmac.getmac._popen", return_value=content)
    assert mac == benchmark(getmac.ArpFreebsd().get, arg=ip)

    assert not getmac.ArpFreebsd().get("")
    assert not getmac.ArpFreebsd().get("10.")
    assert not getmac.ArpFreebsd().get("10.10.10.10")
    assert not getmac.ArpFreebsd().get(mac)
    assert not getmac.ArpFreebsd().get("em0")

    mocker.patch("getmac.getmac.check_command", return_value=True)
    assert getmac.ArpFreebsd().test() is True
    getmac.check_command.assert_called_once_with("arp")


@pytest.mark.parametrize(
    ("mac", "ip", "sample_file"),
    [
        ("00:50:56:f1:4c:50", "192.168.16.2", "ubuntu_18.04/cat_proc-net-arp.out"),
        ("00:50:56:e1:a8:4a", "192.168.16.2", "ubuntu_18.10/proc_net_arp.out"),
        ("00:50:56:e8:32:3c", "192.168.16.254", "ubuntu_18.10/proc_net_arp.out"),
        ("00:50:56:c0:00:0a", "192.168.95.1", "ubuntu_18.10/proc_net_arp.out"),
        ("00:50:56:fa:b7:54", "192.168.95.254", "ubuntu_18.10/proc_net_arp.out"),
        ("52:55:0a:00:02:02", "10.0.2.2", "android_6/cat_proc-net-arp.out"),
        ("02:00:00:00:01:00", "192.168.232.1", "android_9/cat_proc-net-arp.out"),
        ("8e:8f:aa:c9:d2:8b", "192.168.200.1", "android_9/cat_proc-net-arp.out"),
    ],
)
def test_arpfile_samples(benchmark, mocker, get_sample, mac, ip, sample_file):
    content = get_sample(sample_file)
    mocker.patch("getmac.getmac._read_file", return_value=content)
    assert mac == benchmark(getmac.ArpFile().get, arg=ip)

    assert not getmac.ArpFile().get("0.0.0.0")
    assert not getmac.ArpFile().get("104.0.0.0")
    assert not getmac.ArpFile().get("")
    assert not getmac.ArpFile().get(mac)

    mocker.patch("getmac.getmac._read_file", return_value=None)
    assert not getmac.ArpFile().get(ip)

    mocker.patch("getmac.getmac._read_file", return_value="")
    assert not getmac.ArpFile().get(ip)


@pytest.mark.parametrize(
    ("mac", "ip", "sample_file"),
    [
        (
            "00:50:56:f1:4c:50",
            "192.168.16.2",
            "ubuntu_18.04/ip_neighbor_show_192-168-16-2.out",
        ),
        ("00:50:56:f1:4c:50", "192.168.16.2", "ubuntu_18.04/ip_neighbor_show.out"),
        ("52:55:0a:00:02:02", "10.0.2.2", "android_6/ip_neighbor_show_10.0.2.2.out"),
        ("52:55:0a:00:02:02", "10.0.2.2", "android_6/ip_neighbor.out"),
        ("52:56:00:00:00:02", "fe80::2", "android_6/ip_neighbor.out"),
        ("8e:8f:aa:c9:d2:8b", "192.168.200.1", "android_9/ip_neighbor.out"),
        ("8e:8f:aa:c9:d2:8b", "fe80::8c8f:aaff:fec9:d28b", "android_9/ip_neighbor.out"),
    ],
)
def test_ipneighshow_samples(benchmark, mocker, get_sample, mac, ip, sample_file):
    content = get_sample(sample_file)
    mocker.patch("getmac.getmac._popen", return_value=content)
    assert mac == benchmark(getmac.IpNeighborShow().get, arg=ip)

    assert getmac.IpNeighborShow().get("bad") is None


@pytest.mark.parametrize(
    ("mac", "iface", "sample_file"),
    [
        ("00:0c:29:b5:72:37", "ens33", "ubuntu_18.04/netstat_iae.out"),
        ("02:42:33:bf:3e:40", "docker0", "ubuntu_18.04/netstat_iae.out"),
        ("08:00:27:e8:81:6f", "eth0", "ubuntu_12.04/netstat_iae.out"),
        ("b4:2e:99:35:1e:84", "eth0", "WSL_ubuntu_18.04/netstat_-iae.out"),
        ("0a:00:27:00:00:0c", "eth4", "WSL_ubuntu_18.04/netstat_-iae.out"),
    ],
)
def test_netstatiface_samples(benchmark, mocker, get_sample, mac, iface, sample_file):
    content = get_sample(sample_file)
    mocker.patch("getmac.getmac._popen", return_value=content)

    assert mac == benchmark(getmac.NetstatIface().get, arg=iface)
    assert getmac.NetstatIface().get("lo") is None
    assert getmac.NetstatIface().get("ens") is None
    assert getmac.NetstatIface().get("ens3") is None
    assert getmac.NetstatIface().get("ens333") is None
    assert getmac.NetstatIface().get("docker") is None
    assert getmac.NetstatIface().get("eth") is None
    assert getmac.NetstatIface().get("eth00") is None
    # TODO: improve netstat regex.
    #   On Linux, it uses the same source as ifconfig (the Kernel Interface Table),
    #   so we can just use the same regex that we use for Ifconfig* methods
    # assert getmac.NetstatIface().get("Kernel") is None
    # assert getmac.NetstatIface().get("e") is None

    mocker.patch("getmac.getmac._popen", return_value=None)
    assert getmac.NetstatIface().get("eth0") is None
    mocker.patch("getmac.getmac._popen", return_value=" ")
    assert getmac.NetstatIface().get("eth0") is None


def test_ip_link_iface_bad_returncode(mocker, get_sample):
    """Test the exception handling works for old-style ip link."""
    content = get_sample("ip_link_list.out")
    cpe = CalledProcessError(cmd="", returncode=255)
    mocker.patch("getmac.getmac._popen", side_effect=[cpe, content])
    except_method = getmac.IpLinkIface()
    assert "74:d4:35:e9:45:71" == except_method.get("eth0")


@pytest.mark.parametrize(
    ("expected_mac", "iface_arg"),
    [
        ("b4:2e:99:36:1e:33", "eth0"),
        ("b4:2e:99:35:1e:86", "eth3"),
        ("00:15:5d:83:d9:0a", "eth8"),
        (None, "lo"),
        ("00:ff:36:20:68:56", "eth15"),
        (None, "eth16"),
        (None, "eth"),
    ],
)
def test_ip_link_iface_wsl(benchmark, mocker, get_sample, expected_mac, iface_arg):
    mocker.patch("getmac.getmac.IpLinkIface._tested_arg", True)
    mocker.patch("getmac.getmac.IpLinkIface._iface_arg", False)
    content = get_sample("WSL_ubuntu_18.04/ip_link.out")
    mocker.patch("getmac.getmac._popen", return_value=content)
    assert expected_mac == benchmark(getmac.IpLinkIface().get, arg=iface_arg)


@pytest.mark.parametrize(
    ("mac", "iface", "sample_file"),
    [
        ("08:00:27:12:33:44", "eth0", "ubuntu_18.04/ip_link_show_eth0.out"),
        ("00:0c:29:b5:72:37", "ens33", "ubuntu_18.04/ip_link_list.out"),
        ("00:0c:29:b5:72:37", "ens33", "ubuntu_18.04/ip_link.out"),
        ("74:d4:35:e9:45:71", "eth0", "ip_link_list.out"),
        ("52:54:00:12:34:56", "eth0", "android_6/ip_link.out"),
        ("46:37:e2:ae:b8:7f", "radio0@if10", "android_9/ip_link.out"),
    ],
)
def test_iplinkiface_samples(benchmark, mocker, get_sample, mac, iface, sample_file):
    content = get_sample(sample_file)
    mocker.patch("getmac.getmac._popen", return_value=content)
    assert mac == benchmark(getmac.IpLinkIface().get, arg=iface)

    # TODO: IpLinkIface regexes need improvements
    # assert getmac.IpLinkIface().get("eth") is None
    # assert getmac.IpLinkIface().get("et") is None
    # assert getmac.IpLinkIface().get("e") is None
    assert getmac.IpLinkIface().get("e0") is None
    assert getmac.IpLinkIface().get("en33") is None
    assert getmac.IpLinkIface().get("sit0") is None
    assert getmac.IpLinkIface().get("radio@if10") is None
    # assert getmac.IpLinkIface().get("") is None


@pytest.mark.parametrize(
    ("expected_iface", "sample_file"),
    [
        ("ens33", "ubuntu_18.04/route_-n.out"),
        ("eth0", "WSL_ubuntu_18.04/route_-n.out"),
        ("eth0", "android_6/route_-n.out"),
    ],
)
def test_default_iface_route_command(
    benchmark, mocker, get_sample, expected_iface, sample_file
):
    content = get_sample(sample_file)
    mocker.patch("getmac.getmac._popen", return_value=content)
    assert expected_iface == benchmark(getmac.DefaultIfaceRouteCommand().get)

    mocker.patch("getmac.getmac._popen", return_value="")
    assert not getmac.DefaultIfaceRouteCommand().get()

    mocker.patch("getmac.getmac._popen", return_value="0.0.0.0 ")
    assert not getmac.DefaultIfaceRouteCommand().get()


@pytest.mark.parametrize(
    ("iface", "sample_file"),
    [
        ("ens33", "ubuntu_18.10/proc_net_route.out"),
        ("eth0", "android_6/cat_proc-net-route.out"),
        (None, "android_9/cat_proc-net-route.out"),
    ],
)
def test_defaultifacelinuxroutefile_samples(
    benchmark, mocker, get_sample, iface, sample_file
):
    content = get_sample(sample_file)
    mocker.patch("getmac.getmac._read_file", return_value=content)
    assert benchmark(getmac.DefaultIfaceLinuxRouteFile().get) == iface


def test_defaultifacelinuxroutefile(mocker):
    mocker.patch("getmac.getmac._read_file", return_value=None)
    assert getmac.DefaultIfaceLinuxRouteFile().get() is None

    mocker.patch("getmac.getmac._read_file", return_value="")
    assert getmac.DefaultIfaceLinuxRouteFile().get() is None


@pytest.mark.parametrize(
    ("iface", "sample_file"),
    [
        ("ens33", "ubuntu_18.04/ip_route_list_0slash0.out"),
        ("eth0", "WSL_ubuntu_18.04/ip_route_list_0slash0.out"),
        ("eth0", "android_6/ip_route_list_0slash0.out"),
    ],
)
def test_defaultifaceiproute_samples(benchmark, mocker, get_sample, iface, sample_file):
    content = get_sample(sample_file)
    mocker.patch("getmac.getmac._popen", return_value=content)
    assert iface == benchmark(getmac.DefaultIfaceIpRoute().get)


def test_defaultifaceiproute(mocker):
    mocker.patch("getmac.getmac._popen", return_value=None)
    assert getmac.DefaultIfaceIpRoute().get() is None

    mocker.patch("getmac.getmac._popen", return_value="")
    assert getmac.DefaultIfaceIpRoute().get() is None

    mocker.patch("getmac.getmac._popen", return_value="asdfalksj3")
    assert not getmac.DefaultIfaceIpRoute().get()


@pytest.mark.parametrize(
    ("iface", "sample_file"),
    [
        ("en0", "macos_10.12.6/route_-n_get_default.out"),
        ("em0", "freebsd11/route_get_default.out"),
    ],
)
def test_defaultifaceroutegetcommand_samples(
    benchmark, mocker, get_sample, iface, sample_file
):
    content = get_sample(sample_file)
    mocker.patch("getmac.getmac._popen", return_value=content)
    assert iface == benchmark(getmac.DefaultIfaceRouteGetCommand().get)

    mocker.patch("getmac.getmac._popen", return_value=None)
    assert not getmac.DefaultIfaceRouteGetCommand().get()

    mocker.patch("getmac.getmac._popen", return_value="")
    assert not getmac.DefaultIfaceRouteGetCommand().get()

    # test with bad input (hit the except indexerror case)
    mocker.patch("getmac.getmac._popen", return_value="interface:")
    assert not getmac.DefaultIfaceRouteGetCommand().get()

    mocker.patch("getmac.getmac.check_command", return_value=True)
    assert getmac.DefaultIfaceRouteGetCommand().test() is True
    getmac.check_command.assert_called_once_with("route")


@pytest.mark.parametrize(
    ("mac", "ip", "sample_file"),
    [
        ("58:6d:8f:07:c9:94", "192.168.1.1", "OSX/arp_-a.out"),
        ("58:6d:8f:07:c9:94", "192.168.1.1", "OSX/arp_-an.out"),
        ("00:50:56:f1:4c:50", "192.168.16.2", "ubuntu_18.04/arp_-a.out"),
        ("00:50:56:f1:4c:50", "192.168.16.2", "ubuntu_18.04/arp_-an.out"),
        ("52:54:00:12:35:02", "10.0.2.2", "freebsd11/arp_10-0-2-2.out"),
        ("52:54:00:12:35:02", "10.0.2.2", "solaris10/arp_10-0-2-2.out"),
    ],
)
def test_arp_various_args(benchmark, mocker, get_sample, mac, ip, sample_file):
    content = get_sample(sample_file)
    mocker.patch("getmac.getmac._popen", return_value=content)
    if "OSX" in sample_file:
        mocker.patch("getmac.getmac.DARWIN", return_value=True)
    elif "solaris" in sample_file:
        mocker.patch("getmac.getmac.SOLARIS", return_value=True)
    result = benchmark(getmac.ArpVariousArgs().get, arg=ip)

    # NOTE: Darwin  and Solaris will return MACs without leading zeroes,
    # e.g. "58:6d:8f:7:c9:94" instead of "58:6d:8f:07:c9:94"
    #
    # It makes more sense to me to just handle the weird mac here
    # in the test instead of adding redundant logic for cleaning
    # the result to the method.
    if "OSX" in sample_file:
        assert result == "58:6d:8f:7:c9:94"
    elif "solaris" in sample_file:
        assert result == "52:54:0:12:35:2"
    if "OSX" in sample_file or "solaris" in sample_file:
        result = getmac._clean_mac(result)

    assert mac == result


def test_sys_iface_file(mocker):
    mocker.patch("getmac.getmac._read_file", return_value="00:0c:29:b5:72:37\n")
    assert getmac.SysIfaceFile().get("ens33") == "00:0c:29:b5:72:37\n"

    mocker.patch("getmac.getmac._read_file", return_value=None)
    assert getmac.SysIfaceFile().get("ens33") is None


@pytest.mark.skipif(
    platform.system() != "Linux",
    reason="Can't reliably mock fcntl on non-Linux platforms",
)
def test_fcntl_iface(mocker):
    data = (
        b"enp3s0\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x01\x00t\xd45\xe9"
        b"Es\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
    )
    mocker.patch("fcntl.ioctl", return_value=data)
    m = mocker.patch("socket.socket")
    assert getmac.FcntlIface().get("enp3s0") == "74:d4:35:e9:45:73"
    m.assert_called_once_with(socket.AF_INET, socket.SOCK_DGRAM)


# Python 2.7.5 (CentOS 7) doesn't have this...
# The commit adding it: https://bit.ly/2Hnd7bN (no idea what release it was in)
@pytest.mark.skipif(
    not hasattr(uuid, "_arp_getnode"),
    reason="This version of Python doesn't have uuid._arp_getnode",
)
def test_uuid_arp_get_node(mocker):
    mocker.patch("uuid._arp_getnode", return_value=278094213753144)
    assert getmac.UuidArpGetNode().get("10.0.0.1") == "FC:EC:DA:D3:29:38"
    mocker.patch("uuid._arp_getnode", return_value=None)
    assert getmac.UuidArpGetNode().get("10.0.0.1") is None
    assert getmac.UuidArpGetNode().get("en0") is None


@pytest.mark.skipif(
    sys.version_info[0] == 3 and sys.version_info[1] >= 9,
    reason="Python 3.9+ doesn't have uuid._find_mac",
)
def test_uuid_lanscan(mocker):
    mocker.patch("uuid._find_mac", return_value=2482700837424)
    assert getmac.UuidLanscan().get("en1") == "02:42:0C:80:62:30"
    mocker.patch("uuid._find_mac", return_value=None)
    assert getmac.UuidLanscan().get("10.0.0.1") is None
    assert getmac.UuidLanscan().get("en0") is None

    mocker.patch("getmac.getmac.check_command", return_value=True)
    assert getmac.UuidLanscan().test() is True
    getmac.check_command.assert_called_once_with("lanscan")



# -*- coding: utf-8 -*-

import inspect
import sys
from subprocess import CalledProcessError

import pytest

from getmac import get_mac_address, getmac

PY2 = sys.version_info[0] == 2
MAC_RE_COLON = r"([0-9a-fA-F]{2}(?::[0-9a-fA-F]{2}){5})"


def test_all_methods_defined_are_in_methods_list():
    """Test that all methods present in getmac.py are in the METHODS list."""

    def _is_method(member):
        return (
            inspect.isclass(member)
            and issubclass(member, getmac.Method)
            and member is not getmac.Method
        )

    members = [m[1] for m in inspect.getmembers(getmac, _is_method)]
    assert set(members) == set(getmac.METHODS)
    assert len(members) == len(getmac.METHODS)


def test_method_platform_strings_are_valid():
    """test "platforms" for all methods have a valid platform name."""
    for method in getmac.METHODS:
        assert method.platforms <= getmac.Method.VALID_PLATFORM_NAMES


def test_check_path():
    assert getmac.check_path(__file__)


def test_clean_mac():
    assert getmac._clean_mac(None) is None
    assert getmac._clean_mac("") is None
    assert getmac._clean_mac("00:00:00:00:00:00:00:00:00") is None
    assert getmac._clean_mac("00:0000:0000") is None
    assert getmac._clean_mac("00000000000000000") is None
    assert getmac._clean_mac("  00-50-56-C0-00-01  ") == "00:50:56:c0:00:01"
    assert getmac._clean_mac("000000000000") == "00:00:00:00:00:00"


def test_search(get_sample):
    text = get_sample("ifconfig.out")
    regex = r"HWaddr " + MAC_RE_COLON
    assert getmac._search(regex, "") is None
    assert getmac._search(regex, text, 0) == "74:d4:35:e9:45:71"


def test_popen(mocker):
    mocker.patch("getmac.getmac.PATH", [])
    m = mocker.patch("getmac.getmac._call_proc", return_value="SUCCESS")
    assert getmac._popen("TESTCMD", "ARGS") == "SUCCESS"
    m.assert_called_once_with("TESTCMD", "ARGS")


def test_call_proc(mocker):
    mocker.patch("getmac.getmac.DEVNULL", "DEVNULL")
    mocker.patch("getmac.getmac.ENV", "ENV")

    mocker.patch("getmac.getmac.WINDOWS", True)
    m = mocker.patch("getmac.getmac.check_output", return_value="WINSUCCESS")
    assert getmac._call_proc("CMD", "arg") == "WINSUCCESS"
    m.assert_called_once_with("CMD" + " " + "arg", stderr="DEVNULL", env="ENV")

    mocker.patch("getmac.getmac.WINDOWS", False)
    m = mocker.patch("getmac.getmac.check_output", return_value="YAY")
    assert getmac._call_proc("CMD", "arg1 arg2") == "YAY"
    m.assert_called_once_with(["CMD", "arg1", "arg2"], stderr="DEVNULL", env="ENV")


def test_uuid_convert():
    assert getmac._uuid_convert(2482700837424) == "02:42:0C:80:62:30"
    assert getmac._uuid_convert(278094213753144) == "FC:EC:DA:D3:29:38"


def test_read_file_return(mocker, get_sample):
    data = get_sample("ifconfig.out")
    mock_open = mocker.mock_open(read_data=data)
    if PY2:
        mocker.patch("__builtin__.open", mock_open)
    else:
        mocker.patch("builtins.open", mock_open)
    assert getmac._read_file("ifconfig.out") == data
    mock_open.assert_called_once_with("ifconfig.out")


def test_read_file_not_exist():
    assert getmac._read_file("DOESNOTEXIST") is None


def test_fetch_ip_using_dns(mocker):
    m = mocker.patch("socket.socket")
    m.return_value.getsockname.return_value = ("1.2.3.4", 51327)
    assert getmac._fetch_ip_using_dns() == "1.2.3.4"


def test_get_method_by_name():
    assert not getmac.get_method_by_name("")
    assert not getmac.get_method_by_name("invalidmethodname")
    assert getmac.get_method_by_name("ArpFile") == getmac.ArpFile
    assert getmac.get_method_by_name("getmacexe") == getmac.GetmacExe


def test_get_instance_from_cache(mocker):
    with pytest.raises(KeyError):
        getmac.get_instance_from_cache("", "")

    inst = getmac.ArpFile()
    mocker.patch("getmac.getmac.METHOD_CACHE", {"ip4": inst})
    assert getmac.get_instance_from_cache("ip4", "ArpFile") is inst

    mocker.patch("getmac.getmac.METHOD_CACHE", {"ip4": None})
    assert getmac.get_instance_from_cache("ip4", "ArpFile") is None


def test_swap_method_fallback(mocker):
    mocker.patch("getmac.getmac.METHOD_CACHE", {"ip4": getmac.ArpExe()})
    mocker.patch("getmac.getmac.FALLBACK_CACHE", {"ip4": [getmac.CtypesHost()]})
    assert getmac._swap_method_fallback("ip4", "ArpExe")
    assert not getmac._swap_method_fallback("ip4", "InvalidMethod")
    assert getmac._swap_method_fallback("ip4", "CtypesHost")
    assert isinstance(getmac.METHOD_CACHE["ip4"], getmac.Method)
    assert str(getmac.METHOD_CACHE["ip4"]) == "CtypesHost"
    assert isinstance(getmac.FALLBACK_CACHE["ip4"][0], getmac.Method)
    assert str(getmac.FALLBACK_CACHE["ip4"][0]) == "ArpExe"


@pytest.mark.parametrize("method_type", ["ip4", "ip6", "iface", "default_iface"])
def test_initialize_method_cache_valid_types(mocker, method_type):
    mocker.patch(
        "getmac.getmac.METHOD_CACHE",
        {"ip4": None, "ip6": None, "iface": None, "default_iface": None},
    )
    mocker.patch("getmac.getmac.FALLBACK_CACHE", {})
    mocker.patch("getmac.getmac.PLATFORM", "linux")
    assert getmac.initialize_method_cache(method_type)
    assert getmac.METHOD_CACHE[method_type] is not None
    if method_type in ["ip4", "ip6"]:
        assert getmac.FALLBACK_CACHE[method_type]


def test_initialize_method_cache_initialized(mocker):
    mocker.patch(
        "getmac.getmac.METHOD_CACHE",
        {"ip4": getmac.ArpFile(), "ip6": None, "iface": None, "default_iface": None},
    )
    mocker.patch("getmac.getmac.FALLBACK_CACHE", {})
    mocker.patch("getmac.getmac.PLATFORM", "linux")
    assert getmac.initialize_method_cache("ip4")
    assert str(getmac.METHOD_CACHE["ip4"]) == "ArpFile"
    assert isinstance(getmac.METHOD_CACHE["ip4"], getmac.Method)


def test_initialize_method_cache_bad_type(mocker):
    mocker.patch(
        "getmac.getmac.METHOD_CACHE",
        {"ip4": None, "ip6": None, "iface": None, "default_iface": None},
    )
    mocker.patch("getmac.getmac.FALLBACK_CACHE", {})
    mocker.patch("getmac.getmac.PLATFORM", "linux")
    with pytest.warns(RuntimeWarning):
        assert not getmac.initialize_method_cache("invalid_method_type")
    with pytest.warns(RuntimeWarning):
        assert not getmac.initialize_method_cache("ip")


def test_initialize_method_cache_platform_override(mocker):
    mocker.patch("getmac.getmac.METHODS", [getmac.GetmacExe, getmac.IfconfigEther])
    mocker.patch(
        "getmac.getmac.METHOD_CACHE",
        {"ip4": None, "ip6": None, "iface": None, "default_iface": None},
    )
    mocker.patch("getmac.getmac.FALLBACK_CACHE", {})
    mocker.patch("getmac.getmac.PLATFORM", "windows")
    mocker.patch("getmac.getmac.OVERRIDE_PLATFORM", "darwin")
    mocker.patch("getmac.getmac.check_command", return_value=True)
    assert getmac.initialize_method_cache("iface")
    assert getmac.OVERRIDE_PLATFORM == "darwin"
    assert getmac.PLATFORM == "windows"
    assert isinstance(getmac.METHOD_CACHE["iface"], getmac.IfconfigEther)


def test_initialize_method_cache_no_network_request(mocker):
    mocker.patch(
        "getmac.getmac.METHOD_CACHE",
        {"ip4": None, "ip6": None, "iface": None, "default_iface": None},
    )
    mocker.patch("getmac.getmac.FALLBACK_CACHE", {})
    mocker.patch("getmac.getmac.PLATFORM", "linux")
    mocker.patch("getmac.getmac.check_command", return_value=True)
    mocker.patch("getmac.getmac.check_path", return_value=True)
    assert getmac.initialize_method_cache("ip4", network_request=False)
    assert getmac.PLATFORM == "linux"
    assert isinstance(getmac.METHOD_CACHE["ip4"], getmac.ArpFile)


def test_get_by_method(mocker, get_sample):
    mocker.patch(
        "getmac.getmac.METHOD_CACHE",
        {
            "ip4": getmac.ArpExe(),
            "ip6": getmac.IpNeighborShow(),
            "iface": getmac.WmicExe(),
            "default_iface": getmac.DefaultIfaceOpenBsd(),
        },
    )

    # ip4
    content = get_sample("windows_10/arp_-a_10.0.0.175.out")
    mocker.patch("getmac.getmac._popen", return_value=content)
    assert getmac.get_by_method("ip4", "10.0.0.175") == "78-28-ca-c4-66-fe"

    # ip6
    content = get_sample("android_9/ip_neighbor.out")
    mocker.patch("getmac.getmac._popen", return_value=content)
    assert (
        getmac.get_by_method("ip6", "fe80::8c8f:aaff:fec9:d28b") == "8e:8f:aa:c9:d2:8b"
    )

    # iface
    content = get_sample("windows_10/wmic_nic.out")
    mocker.patch("getmac.getmac._popen", return_value=content)
    assert getmac.get_by_method("iface", "Ethernet 3") == "00:FF:17:15:F8:C8"

    # default_iface
    content = get_sample("openbsd_6/route_nq_show_inet_gateway_priority_1.out")
    mocker.patch("getmac.getmac._popen", return_value=content)
    assert getmac.get_by_method("default_iface") == "em0"


def test_get_by_method_errors(mocker):
    assert getmac.get_by_method("iface", arg="") is None

    mocker.patch(
        "getmac.getmac.METHOD_CACHE",
        {"ip4": None, "ip6": None, "iface": None, "default_iface": None},
    )
    mocker.patch("getmac.getmac.initialize_method_cache", return_value=False)
    assert getmac.get_by_method("iface", arg="ens33") is None

    mocker.patch("getmac.getmac.initialize_method_cache", return_value=True)
    assert getmac.get_by_method("iface", arg="ens33") is None

    mocker.patch(
        "getmac.getmac.METHOD_CACHE",
        {
            "ip4": None,
            "ip6": None,
            "iface": getmac.SysIfaceFile(),
            "default_iface": None,
        },
    )
    mocker.patch("getmac.getmac._read_file", return_value="")
    mocker.patch("getmac.getmac.DEBUG", 1)
    assert getmac.get_by_method("iface", arg="ens33") is None


def test_get_by_method_force_method(mocker):
    mocker.patch("getmac.getmac.FORCE_METHOD", "testing123")
    assert getmac.get_by_method("iface", arg="some_arg") is None

    mocker.patch("getmac.getmac._read_file", return_value="00:0c:29:b5:72:37\n")
    mocker.patch("getmac.getmac.FORCE_METHOD", "SysIfaceFile")
    assert getmac.get_by_method("iface", "ens33") == "00:0c:29:b5:72:37\n"


def test_get_mac_address_force_method(mocker):
    mocker.patch("getmac.getmac._read_file", return_value="00:0c:29:b5:72:37\n")
    mocker.patch("getmac.getmac.FORCE_METHOD", "SysIfaceFile")
    assert getmac.get_mac_address(interface="ens33") == "00:0c:29:b5:72:37"


def test_get_mac_address_localhost():
    assert get_mac_address(hostname="localhost") == "00:00:00:00:00:00"
    assert get_mac_address(ip="127.0.0.1") == "00:00:00:00:00:00"

    result = get_mac_address(hostname="localhost", network_request=False)
    assert result == "00:00:00:00:00:00"


def test_get_mac_address_interface(mocker):
    mocker.patch("getmac.getmac.get_by_method", return_value="00:0c:29:b5:72:37")
    assert getmac.get_mac_address(interface="ens33") == "00:0c:29:b5:72:37"
    getmac.get_by_method.assert_called_once_with("iface", "ens33")


def test_get_mac_address_ip(mocker):
    mocker.patch("getmac.getmac.get_by_method", return_value="00:01:02:04:00:12")
    assert getmac.get_mac_address(ip="192.0.2.2") == "00:01:02:04:00:12"
    getmac.get_by_method.assert_called_once_with("ip4", "192.0.2.2")


def test_get_mac_address_ip6(mocker):
    mocker.patch("socket.has_ipv6", False)
    assert getmac.get_mac_address(ip6="fe80::1") is None

    mocker.patch("socket.has_ipv6", True)
    assert getmac.get_mac_address(ip6="192.168.0.1") is None

    mocker.patch("getmac.getmac.get_by_method", return_value="00:01:02:04:00:00")
    assert getmac.get_mac_address(ip6="fe80::1") == "00:01:02:04:00:00"
    getmac.get_by_method.assert_called_once_with("ip6", "fe80::1")


def test_get_mac_address_hostname(mocker):
    cpe = CalledProcessError(cmd="socket.gaierror", returncode=1)
    mocker.patch("socket.gethostbyname", side_effect=cpe)
    assert getmac.get_mac_address(hostname="bogus") is None

    mocker.patch("socket.gethostbyname", return_value="192.0.2.22")
    mocker.patch("getmac.getmac.get_by_method", return_value="00:01:02:04:00:22")
    assert getmac.get_mac_address(hostname="test_hostname") == "00:01:02:04:00:22"
    getmac.get_by_method.assert_called_once_with("ip4", "192.0.2.22")


def test_get_mac_address_default_args_windows_net_request_true(mocker):
    mocker.patch("getmac.getmac.WINDOWS", True)
    mocker.patch("getmac.getmac.get_by_method", return_value="00:FF:17:15:F8:C8")
    assert getmac.get_mac_address(network_request=False) == "00:ff:17:15:f8:c8"
    getmac.get_by_method.assert_called_once_with("iface", "Ethernet")

    mocker.patch("getmac.getmac.get_by_method", return_value="78:28:ca:c4:66:fe")
    mocker.patch("getmac.getmac._fetch_ip_using_dns", return_value="10.0.0.175")
    assert getmac.get_mac_address(network_request=True) == "78:28:ca:c4:66:fe"
    getmac.get_by_method.assert_called_once_with("ip4", "10.0.0.175")


def test_get_mac_address_default_args_fallback_global(mocker):
    mocker.patch("getmac.getmac.WINDOWS", False)
    mocker.patch("getmac.getmac.DEFAULT_IFACE", "eth0")
    mocker.patch("getmac.getmac.get_by_method", return_value="08:00:27:e8:81:6f")
    assert getmac.get_mac_address() == "08:00:27:e8:81:6f"
    getmac.get_by_method.assert_called_once_with("iface", "eth0")



# -*- coding: utf-8 -*-

import platform
import sys
from subprocess import PIPE, Popen

import pytest

from getmac import __version__, get_mac_address

PY2 = sys.version_info[0] == 2
BASE_CMD = [sys.executable, "-m", "getmac"]


def run_cmd(command):
    # type: (list) -> str
    stdout, _ = Popen(command, stdout=PIPE, stderr=PIPE).communicate()
    return stdout.decode("utf-8").strip()


def test_cli_main_basic():
    assert run_cmd(BASE_CMD) == get_mac_address()


def test_cli_main_verbose():
    assert get_mac_address() in run_cmd(BASE_CMD + ["--verbose"])


def test_cli_main_debug():
    assert get_mac_address() in run_cmd(BASE_CMD + ["--verbose", "--debug"])


def test_cli_main_invalid_interface():
    assert run_cmd(BASE_CMD + ["--interface", "INVALIDTESTINTERFACE"]) == ""


def test_cli_help():
    assert run_cmd(BASE_CMD + ["--help"]) != ""


@pytest.mark.skipif(
    PY2,
    reason="This doesn't work in Python 2.7 "
    "and I don't care enough to figure out why",
)
def test_cli_version():
    assert __version__ in run_cmd(BASE_CMD + ["--version"])


def test_cli_multiple_debug_levels():
    assert get_mac_address() in run_cmd(BASE_CMD + ["-v", "-dd"])
    assert get_mac_address() in run_cmd(BASE_CMD + ["-v", "-ddd"])
    assert get_mac_address() in run_cmd(BASE_CMD + ["-v", "-dddd"])


def test_cli_no_net():
    assert get_mac_address(hostname="localhost") in run_cmd(
        BASE_CMD + ["-n", "localhost", "--no-network-requests"]
    )


def test_cli_override_port():
    assert (
        run_cmd(BASE_CMD + ["-v", "-dd", "-4", "127.0.0.1", "--override-port", "44444"])
        != ""
    )


def test_cli_localhost():
    assert run_cmd(BASE_CMD + ["-4", "127.0.0.1"]) != ""
    assert run_cmd(BASE_CMD + ["-n", "localhost"]) != ""
    assert run_cmd(BASE_CMD + ["--no-network-requests", "-4", "127.0.0.1"]) != ""
    assert run_cmd(BASE_CMD + ["--no-network-requests", "-n", "localhost"]) != ""


# TODO: figure out how to properly test CLI commands and isolate platform-specific behavior
def test_cli_override_platform():
    plat = platform.system().lower()
    assert run_cmd(BASE_CMD + ["-v", "-dd", "--override-platform", plat]) != ""



#!/usr/bin/env python
# -*- coding: utf-8 -*-

import sys
from io import open  # Python 2 compatibility

from setuptools import setup

from getmac.getmac import __version__


# Build the page that will be displayed on PyPI from the README and CHANGELOG
with open("README.md", encoding="utf-8") as f:
    long_description = f.read()
long_description += "\n\n"
with open("CHANGELOG.md", encoding="utf-8") as f:
    long_description += f.read()


setup(
    name="getmac",
    version=__version__,
    author="Christopher Goes",
    author_email="ghostofgoes@gmail.com",
    description="Get MAC addresses of remote hosts and local interfaces",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/GhostofGoes/getmac",
    project_urls={
        # "Documentation": "https://getmac.readthedocs.io/en/latest/",
        "Changelog": "https://github.com/GhostofGoes/getmac/blob/main/CHANGELOG.md",
        "Issue tracker": "https://github.com/GhostofGoes/getmac/issues",
        "Source": "https://github.com/GhostofGoes/getmac",
        "Discord server": "https://discord.gg/python",
    },
    license="MIT",
    data_files=[],
    packages=["getmac"],
    zip_safe=True,
    entry_points={"console_scripts": ["getmac2 = getmac.__main__:main"]}
    if sys.version_info[:2] <= (2, 7)
    else {"console_scripts": ["getmac = getmac.__main__:main"]},
    install_requires=[],
    python_requires=">=2.7, !=3.0.*, !=3.1.*, !=3.2.*, !=3.3.*",
    keywords=[
        "getmac",
        "get-mac",
        "macaddress",
        "mac-address",
        "mac",
        "ethernet",
        "mac-48",
        "networking",
        "network",
        "networking",
        "layer2",
        "layer-2",
        "802.3",
    ],
    classifiers=[  # TODO(python3): update classifiers
        # TODO(1.0.0): change to 5 - Production/Stable
        "Development Status :: 4 - Beta",
        "Environment :: Console",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Operating System :: Microsoft :: Windows",
        "Operating System :: POSIX",
        "Operating System :: MacOS",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.4",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Programming Language :: Python :: 2",
        "Programming Language :: Python :: 2.7",
        "Programming Language :: Python :: Implementation :: CPython",
        "Programming Language :: Python :: Implementation :: PyPy",
        "Programming Language :: Python :: Implementation :: IronPython",
        "Programming Language :: Python :: Implementation :: Jython",
        "Intended Audience :: Developers",
        "Intended Audience :: System Administrators",
        "Intended Audience :: Information Technology",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "Topic :: Software Development :: Libraries",
        "Topic :: System :: Systems Administration",
        "Topic :: System :: Networking",
        "Topic :: Utilities",
    ],
)
